@@ -1,9 +1,9 @@
 from interage.api.models.base import APIModel, APIMetadataModel, json_to_instance_list
-from interage.api.models.json import APIJsonResult
+from interage.api.models.result import APIResult
 from interage.api.models.models import (PrincipioAtivo, Medicamento, Interacao)
 
 
 __all__ = [
-    'APIJsonResult', 'APIModel',  'APIMetadataModel', 'json_to_instance_list',
+    'APIResult', 'APIModel',  'APIMetadataModel', 'json_to_instance_list',
     'PrincipioAtivo', 'Medicamento', 'Interacao',
 ]
